Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(264)

Unified Diff: sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart

Issue 306693002: Remove support for the special "assets" directory. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart
diff --git a/sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart b/sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart
index 380a1153292d6e02a5ef357f858376a05bce937c..6661940d12a734d13fd3eef77cc4ec132c2e75f0 100644
--- a/sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart
+++ b/sdk/lib/_internal/pub/test/build/includes_assets_from_dependencies_test.dart
@@ -10,14 +10,14 @@ import '../test_pub.dart';
main() {
initConfig();
- integration("includes assets from dependencies", () {
+ integration("includes assets from the 'lib' directory of dependencies", () {
// Dart2js can take a long time to compile dart code, so we increase the
// timeout to cope with that.
currentSchedule.timeout *= 3;
d.dir("foo", [
d.libPubspec("foo", "0.0.1"),
- d.dir("asset", [
+ d.dir("lib", [
d.file("foo.txt", "foo"),
d.dir("sub", [
d.file("bar.txt", "bar"),
@@ -47,7 +47,7 @@ main() {
d.dir('build', [
d.dir('example', [
d.file("index.html", "html"),
- d.dir('assets', [
+ d.dir('packages', [
d.dir('foo', [
d.file('foo.txt', 'foo'),
d.dir('sub', [
@@ -58,7 +58,7 @@ main() {
]),
d.dir('web', [
d.file("index.html", "html"),
- d.dir('assets', [
+ d.dir('packages', [
d.dir('foo', [
d.file('foo.txt', 'foo'),
d.dir('sub', [
@@ -68,8 +68,8 @@ main() {
]),
d.dir("sub", [
d.file("index.html", "html"),
- // "assets" should *only* be created in the top-level directory.
- d.nothing("assets")
+ // "packages" should *only* be created in the top-level directory.
+ d.nothing("packages")
])
])
])

Powered by Google App Engine
This is Rietveld 408576698